****************
canonical-sphinx
****************

Extension and theme to create great Canonical-branded documentation.

Description
-----------
TODO

Structure
---------
TODO

How to migrate existing projects
--------------------------------
TODO


.. _EditorConfig: https://editorconfig.org/
.. _pre-commit: https://pre-commit.com/
.. _ReadTheDocs: https://docs.readthedocs.io/en/stable/intro/import-guide.html
.. _use this template: https://docs.github.com/en/repositories/creating-and-managing-repositories/creating-a-repository-from-a-template
